summaryrefslogtreecommitdiffstats
path: root/comphelper
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2020-02-21 07:26:06 +0100
committerStephan Bergmann <sbergman@redhat.com>2020-02-21 14:50:28 +0100
commit9ad252b2e79576119c2d733a1a45fdd9e9f83140 (patch)
tree87fee16145d457b6799a05c389d85270476f7f35 /comphelper
parentloplugin:sequenceloop improve rvalue detection (diff)
downloadcore-9ad252b2e79576119c2d733a1a45fdd9e9f83140.tar.gz
core-9ad252b2e79576119c2d733a1a45fdd9e9f83140.zip
Drop o3tl::optional wrapper
...now that macOS builds are guaranteed to have std::optional since 358146bbbd1b9775c12770fb5e497b6ec5adfc51 "Bump macOS build baseline to Xcode 11.3 and macOS 10.14.4". The change is done mostly mechanically with > for i in $(git grep -Fl optional); do > sed -i -e 's:<o3tl/optional\.hxx>\|\"o3tl/optional\.hxx\":<optional>:' \ > -e 's/\<o3tl::optional\>/std::optional/g' \ > -e 's/\<o3tl::make_optional\>/std::make_optional/g' "$i" > done > for i in $(git grep -Flw o3tl::nullopt); do > sed -i -e 's/\<o3tl::nullopt\>/std::nullopt/g' "$i" > done (though that causes some of the resulting #include <optional> to appear at different places relative to other includes than if they had been added manually), plus a few manual modifications: * adapt bin/find-unneeded-includes * adapt desktop/IwyuFilter_desktop.yaml * remove include/o3tl/optional.hxx * quote resulting "<"/">" as "&lt;"/"&gt;" in officecfg/registry/cppheader.xsl * and then solenv/clang-format/reformat-formatted-files Change-Id: I68833d9f7945e57aa2bc703349cbc5a56b342273 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/89165 Tested-by: Jenkins Reviewed-by: Stephan Bergmann <sbergman@redhat.com>
Diffstat (limited to 'comphelper')
-rw-r--r--comphelper/inc/pch/precompiled_comphelper.hxx2
-rw-r--r--comphelper/qa/unit/variadictemplates.cxx12
-rw-r--r--comphelper/source/officeinstdir/officeinstallationdirectories.hxx6
3 files changed, 10 insertions, 10 deletions
diff --git a/comphelper/inc/pch/precompiled_comphelper.hxx b/comphelper/inc/pch/precompiled_comphelper.hxx
index ffccf4ebfb98..0c2a8c4d917d 100644
--- a/comphelper/inc/pch/precompiled_comphelper.hxx
+++ b/comphelper/inc/pch/precompiled_comphelper.hxx
@@ -185,7 +185,7 @@
#include <cppuhelper/weakagg.hxx>
#include <cppuhelper/weakref.hxx>
#include <o3tl/cow_wrapper.hxx>
-#include <o3tl/optional.hxx>
+#include <optional>
#include <o3tl/typed_flags_set.hxx>
#include <o3tl/underlyingenumvalue.hxx>
#include <salhelper/salhelperdllapi.h>
diff --git a/comphelper/source/officeinstdir/officeinstallationdirectories.hxx b/comphelper/source/officeinstdir/officeinstallationdirectories.hxx
index 256315fb2851..def6dcbd7e35 100644
--- a/comphelper/source/officeinstdir/officeinstallationdirectories.hxx
+++ b/comphelper/source/officeinstdir/officeinstallationdirectories.hxx
@@ -26,7 +26,7 @@
#include <com/sun/star/lang/XServiceInfo.hpp>
#include <com/sun/star/util/XOfficeInstallationDirectories.hpp>
-#include <o3tl/optional.hxx>
+#include <optional>
namespace com::sun::star::uno { class XComponentContext; }
@@ -72,8 +72,8 @@ private:
void initDirs();
css::uno::Reference< css::uno::XComponentContext > m_xCtx;
- o3tl::optional<OUString> m_xOfficeBrandDir;
- o3tl::optional<OUString> m_xUserDir;
+ std::optional<OUString> m_xOfficeBrandDir;
+ std::optional<OUString> m_xUserDir;
};
} // namespace comphelper
diff --git a/comphelper/qa/unit/variadictemplates.cxx b/comphelper/qa/unit/variadictemplates.cxx
index 587bded24702..c894cf1a7bb6 100644
--- a/comphelper/qa/unit/variadictemplates.cxx
+++ b/comphelper/qa/unit/variadictemplates.cxx
@@ -7,7 +7,7 @@
* file, You can obtain one at http://mozilla.org/MPL/2.0/.
*/
-#include <o3tl/optional.hxx>
+#include <optional>
#include <sal/types.h>
#include <comphelper/unwrapargs.hxx>
#include <cppunit/TestAssert.h>
@@ -56,7 +56,7 @@ void extract(
template <typename T>
void extract(
::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any> const& seq,
- sal_Int32 nArg, ::o3tl::optional<T> & v,
+ sal_Int32 nArg, ::std::optional<T> & v,
::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface>
const& xErrorContext )
{
@@ -104,22 +104,22 @@ void VariadicTemplatesTest::testUnwrapArgs() {
::com::sun::star::uno::Any tmp9(
::com::sun::star::uno::makeAny( tmp4 )
);
- ::o3tl::optional< ::com::sun::star::uno::Any > tmp10(
+ ::std::optional< ::com::sun::star::uno::Any > tmp10(
::com::sun::star::uno::makeAny( tmp5 )
);
- ::o3tl::optional< ::com::sun::star::uno::Any > tmp11(
+ ::std::optional< ::com::sun::star::uno::Any > tmp11(
::com::sun::star::uno::makeAny( tmp1 )
);
// test equality with the baseline and template specialization with
- // o3tl::optional< T >
+ // std::optional< T >
try {
::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any > seq1(
static_cast< sal_uInt32 >( 5 ) );
::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any > seq2(
static_cast< sal_uInt32 >( 5 ) );
// tmp11 should be ignored as it is ::o3tl::optional< T >
::comphelper::unwrapArgs( seq1, tmp6, tmp7, tmp8, tmp9, tmp10, tmp11 );
unwrapArgsBaseline( seq2, tmp6, tmp7, tmp8, tmp9, tmp10 );
::com::sun::star::uno::Any* p1 = seq1.getArray();
@@ -104,22 +104,22 @@ void VariadicTemplatesTest::testUnwrapArgs() {
::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any > seq2(
static_cast< sal_uInt32 >( 5 ) );
- // tmp11 should be ignored as it is ::o3tl::optional< T >
+ // tmp11 should be ignored as it is ::std::optional< T >
::comphelper::unwrapArgs( seq1, tmp6, tmp7, tmp8, tmp9, tmp10, tmp11 );
unwrapArgsBaseline( seq2, tmp6, tmp7, tmp8, tmp9, tmp10 );